==> xc7.2.92.tgz: xc7.2.92/kernel/system.h <==
/* Definitions of system-specific things for Xconq.
   Copyright (C) 1995, 1996, 1997, 1999 Stanley T. Shebs.

Xconq is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.  See the file COPYING.  */

/* Note that this assumes module.h is already included. */

extern FILE *open_module_library_file(Module *module);
extern FILE *open_module_explicit_file(Module *module);
extern FILE *open_library_file(char *filename);
extern char *default_library_pathname(void);
extern char *default_images_pathname(void);
extern char *news_filename(void);
extern char *saved_game_filename(void);
extern char *checkpoint_filename(void);
extern char *error_save_filename(void);
extern char *statistics_filename(void);
extern char *preferences_filename(void);
extern FILE *open_scorefile_for_reading(char *name);
extern FILE *open_scorefile_for_writing(char *name);
extern void close_scorefile_for_writing(FILE *fp);
extern void make_pathname(char *path, char *name, char *extn,
				  char *pathbuf);
extern void remove_saved_game(void);
extern void init_signal_handlers(void);
extern int n_seconds_elapsed(int n);
extern int n_ms_elapsed(int n);
extern void record_ms(void);

extern void open_remote_connection(char *methodname);
extern void close_remote_connection(void);
extern void low_send(int id, char *buf);
extern int low_receive(int *id, char *buf, int maxchars,
				int timeout);

/* defined in init.c but referenced in mac.c ... */
extern void add_library_path(char *path);

extern int serial_port_dialog(void);

==> xc7.2.93.tgz: xc7.2.93/kernel/system.h <==
/* Definitions of system-specific things for Xconq.
   Copyright (C) 1995, 1996, 1997, 1999 Stanley T. Shebs.

Xconq is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.  See the file COPYING.  */

/* Note that this assumes module.h is already included. */

extern FILE *open_module_library_file(Module *module);
extern FILE *open_module_explicit_file(Module *module);
extern FILE *open_library_file(char *filename);
extern char *default_library_pathname(void);
extern char *default_images_pathname(void);
extern char *news_filename(void);
extern char *saved_game_filename(void);
extern char *checkpoint_filename(void);
extern char *error_save_filename(void);
extern char *statistics_filename(void);
extern char *preferences_filename(void);
extern FILE *open_scorefile_for_reading(char *name);
extern FILE *open_scorefile_for_writing(char *name);
extern void close_scorefile_for_writing(FILE *fp);
extern void make_pathname(char *path, char *name, char *extn, char *pathbuf);
extern void remove_saved_game(void);
extern void init_signal_handlers(void);
extern int n_seconds_elapsed(int n);
extern int n_ms_elapsed(int n);
extern void record_ms(void);

extern int open_remote_connection(char *methodname, int willhost);
extern void low_send(int rid, char *buf);
extern int low_receive(int *rid, char *buf, int maxchars, int timeout);
extern void close_remote_connection(int rid);

/* defined in init.c but referenced in mac.c ... */
extern void add_library_path(char *path);

extern int serial_port_dialog(void);
